'''
Resistivity in Less Than Three Dimensions - Contour plotting
University of Toronto. Fall 2010.
Written by Travis Durjan.
Written for Python 2.6.6, numpy 1.5.1, matplotlib 1.0.0
----------
This program reads and processes all files within the specified directory,
regardless of the filename, and creates a contour plot of the data.
Only data files for the desired contour must be kept in the specified folder.

No offset data is required/used as the contours are relative, i.e. a constant
offset will not change its structure. If quantitative analysis is required, an
offset will have to be applied.

It is assumed that the data is taken by keeping the I and P+ probes fixed
and voltages measured as P- is varied.

Probe positions are read from the first line of the first file and will not be
plotted if not present. (It is recommended that positions are present at
the beginning of every file.)

As with Resistivity.py, positions at every point need not be specified, only
a change in position is registered in the program. For more on the parsing
routine used, see toolpy.getcontourdata().
'''

dir = 'oct22 - contour' # directory containing data files
levels = 30 # number of levels in contour plot


# imports
import toolpy as tp
import matplotlib.pyplot as plt

# get position and voltage values from the specified folder
pos,data = tp.getcontourdata(dir)

# prepare data for contour plotting
# (pyplot.contour() requires 2-dim arrays mapped to some grid)
x,y,z = tp.prepcontourdata(data)

plt.figure()
plt.contour(x,y,z,levels) # contour lines
plt.contourf(x,y,z,levels) # fill contours
plt.colorbar()
plt.xlabel('x (cm)')
plt.ylabel('y (cm)')

# try to use scientific notation (requires matplotlib 1.0+)
try: plt.ticklabel_format(style='scientific',axis='both')
except AttributeError: sys.exc_clear()

# plot all data points
#plt.scatter(data[:,0],data[:,1],marker='o',c='b',s=0.1)

def plotpoint(x,y,label):
	if not x or not y:
		print 'Cannot plot {2} at ({0}, {1}).'.format(x,y,label)
	else:
		plt.plot(x,y,'ko',markersize=3.0)
		plt.annotate(label,xy=(x,y),xytext=(x+1,y+1))

# plot and label stationary probes
plotpoint(pos[0],pos[1],'I+')
plotpoint(pos[2],pos[3],'I-')
plotpoint(pos[4],pos[5],'P+')

plt.savefig('{0}\\{1} {2}.png'.format(tp.createdir('pics'),dir,levels))
plt.show()
