#  Resistivity in Less Than Three Dimensions: 1-Dimension
#  University of Toronto.
#  Written by:  Carol McClary       Date:  Fall 2010
#  Programmed for Python

#   This program evaluates voltage data taken for the 1-D experiment and prints \
#   the average resistivity and the error of this value which is the largest \
#   between the propagated error and the standard deviation.  This code assumes \
#   that all position measurements are taken in the x-axis, leaving all y-axis \
#   spaces blank.

from __future__ import division

# variables
foilwidth 	= .00229	#Enter the width of your foil strip (in m)
foilwidtherr	= .00001	#Enter the uncertainty of the width of your foil (in m)
foildepth 	= .000021	#Enter the thickness of your foil strip (in m)
foildeptherr	= .000002	#Enter the uncertainty of the thickness of your foil strip (in m)
pointererr	= .00030	#Enter the uncertainty of the position any one probe (in m)
I = 0.5	# Current value (in A)

#******************************************************

from math	import sqrt #imports square-root function

#   Calculate the cross section area of the foil and its uncertainty
A = foilwidth * foildepth
Aerr = A * sqrt((foilwidtherr/foilwidth) ** 2 + (foildeptherr/foildepth) ** 2)

#   Calculate the error of b (the distance between probes P1 and P2)
berr = sqrt(2 * (pointererr ** 2))

#*******************************************************

#   Open all data files.  Can open more or fewer files depending on need.  
data1 = open('oct15 - 1d\\1D-S-0.5 01.txt','r')
#data2 = open('path.txt','r')
#...
offsetdata = open('oct15 - 1d\\1D-S-0.0 01.txt','r') #data to account for calibration error

#   Reads all data into one list
x = data1.readlines()
#x += data2.readlines()
#...
#   Creates list containing offset data
off = offsetdata.readlines()

#*****************************************************

#   Creates list, c, of all measured voltages in offsetdata.
c = []
for item in off:
    a = 0
    y = 0
    z = []
    while item.find('\t\t', a) != -1: 
        y = item.find('\t\t', a)
        a = y + 1
        z.append(float(item[y+2:item.find('\t\t',a)]))
    c.append(z[3])

#   Finds average of all values in list c
p = 0
n = 0
for result in c:
    p+=result
    n+=1
offset = (p / n)

#*******************************************************

#   Find standard deviation of values in list c to determine the uncertainty 
#   within each voltage reading
#   Note: result is the error of any one voltage measurement
m = 0
for item in c:
	m += (item - offset) ** 2
sd = sqrt((1/(len(c)-1)) * m)
#   Calculate error of the difference between two voltages
Verr = (sqrt(2 * (sd ** 2))) / 1000

#**********************************************************

#   Create a list of resistivity values from given data
resistivities = []

#   Create a list of the errors of resistivities
resistivitieserr = []

for item in x:
    a = 0
    y = 0
    z = []
    while item.find('\t\t', a) != -1:
        y = item.find('\t\t', a)
        a = y + 1
        z.append(float(item[y+2:item.find('\t\t',a)]))

    b = abs(z[1] - z[2]) /100  # Calculate b, convert to m 
    V = (z[3] - offset) /1000	#Calculate V (measured voltage - calibration error), convert to V
    resistivities.append((V*A)/(b*I))
    resistivitieserr.append((V*A)/(b*I)* sqrt(((Verr/V) ** 2) + ((Aerr/A) ** 2) + ((berr/b) ** 2)))

#***************************************************
 
#   Calculate error of the average resistivity value
sum1 = 0
for item in resistivitieserr:
    sum1 += (item ** 2)

p = 0
n = 0
for value in resistivities:
    p += value
    n += 1
error = (sqrt(sum1))/n

#********************************************************

#   Calculate standard deviation of calculated resistivity values
m = 0
for value in resistivities:
    m += (value - p/n) ** 2

stdev = sqrt((1/(n-1)) * m)


#*********************************************************

#   Prints the average resistivity
print 'resistivity:',p/n

#   Prints the propagated error and the standard deviation
print 'err:\t',error,'\nstd:\t',stdev